==> charcoal-0.6.0.zip: charcoal-0.6.0/charcoal/classes/config_providers/IniConfigProvider.class.php <==
<?php
/**
*
* iniեˤ
*
* PHP version 5
*
* @package    config_providers
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class IniConfigProvider extends Object implements IConfigProvider
{

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
		parent::__construct();
	}

	/**
	 * ץХ̾
	 *
	 * @access    public
	 * @return    String
	 */
	public function getProviderName()
	{
		return "INI Config Provider";
	}

	/**
	 * ԥꥪդȥϢŸ
	 *
	 * @access    public
	 * @return    array
	 */
	public function expandPeriod( $config )
	{
		foreach( $config as $key => $value ){
			// ԥꥪɤޤ७򸡺
			$elements = explode('.',$key);
			if ( count($elements) > 1 ){
				$c = &$config;
				$cnt = count($elements);
				for( $i=0; $i<$cnt-1; $i++){
					$e = $elements[$i];
					if ( !isset($c[$e]) ){
						$c[$e] = array();
					}
					$c = &$c[$e];
				}
				$e = $elements[$cnt-1];
				$c[$e] = $value;
			}
		}


		return $config;
	}

	/**
	 *
	 *
	 * @access    public
	 * @param     config_name ̾
	 */
	public function load( $config_root, $config_name )
	{
		log_info( "config",  "ե[$config_name]ɤ߹ߤޤ", __FILE__, __LINE__ );

		$config_file = $config_root . '/' . "$config_name.ini";

		if ( !is_file($config_file) ){			
			log_info( "config",  "ե[$config_file]¸ߤޤ", __FILE__, __LINE__ );
			return NULL;
		}

		// Υ
	    $config = parse_ini_file( $config_file, FALSE );

		// ԥꥪդΥȥϢŸ
		$config = $this->expandPeriod( $config );

		log_info( "config",  "ե[$config_name]ɤ߹ߤޤ", __FILE__, __LINE__ );

		return $config;
	}

}

==> charcoal-0.7.0.zip: charcoal-0.7.0/charcoal/classes/config_providers/IniConfigProvider.class.php <==
<?php
/**
*
* iniեˤ
*
* PHP version 5
*
* @package    config_providers
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class IniConfigProvider extends Object implements IConfigProvider
{

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
		parent::__construct();
	}

	/**
	 * ץХ̾
	 *
	 * @access    public
	 * @return    String
	 */
	public function getProviderName()
	{
		return "INI Config Provider";
	}

	/**
	 * ԥꥪդȥϢŸ
	 *
	 * @access    public
	 * @return    array
	 */
	public function expandPeriod( $config )
	{
		foreach( $config as $key => $value ){
			// ԥꥪɤޤ७򸡺
			$elements = explode('.',$key);
			if ( count($elements) > 1 ){
				$c = &$config;
				$cnt = count($elements);
				for( $i=0; $i<$cnt-1; $i++){
					$e = $elements[$i];
					if ( !isset($c[$e]) ){
						$c[$e] = array();
					}
					$c = &$c[$e];
				}
				$e = $elements[$cnt-1];
				$c[$e] = $value;
			}
		}


		return $config;
	}

	/**
	 *
	 *
	 * @access    public
	 * @param     config_name ̾
	 */
	public function load( $config_root, $config_name )
	{
		log_info( "config",  "ե[$config_name]ɤ߹ߤޤ", __FILE__, __LINE__ );

		$config_file = $config_root . '/' . "$config_name.ini";

		if ( !is_file($config_file) ){			
			log_info( "config",  "ե[$config_file]¸ߤޤ", __FILE__, __LINE__ );
			return NULL;
		}

		// Υ
	    $config = parse_ini_file( $config_file, FALSE );

		// ԥꥪդΥȥϢŸ
		$config = $this->expandPeriod( $config );

//print "config_file:$config_file<BR>";
//print System::arrayToString($config) . "<BR>";

		log_info( "config",  "ե[$config_name]ɤ߹ߤޤ", __FILE__, __LINE__ );

		return $config;
	}

}
return __FILE__;
